{
  am_pm_abbreviated => [
    "\N{U+03c0}.\N{U+03bc}.",
    "\N{U+03bc}.\N{U+03bc}.",
  ],
  available_formats => {
    Bh => "h B",
    Bhm => "h:mm B",
    Bhms => "h:mm:ss B",
    E => "ccc",
    EBhm => "E h:mm B",
    EBhms => "E h:mm:ss B",
    EHm => "E HH:mm",
    EHms => "E HH:mm:ss",
    Ed => "E d",
    Ehm => "E h:mm\N{U+202f}a",
    Ehms => "E h:mm:ss\N{U+202f}a",
    Gy => "y G",
    GyMMM => "LLL y G",
    GyMMMEd => "E d MMM y G",
    GyMMMd => "d MMM y G",
    GyMd => "d/M/y GGGGG",
    H => "HH",
    Hm => "HH:mm",
    Hms => "HH:mm:ss",
    Hmsv => "HH:mm:ss v",
    Hmv => "HH:mm v",
    M => "L",
    MEd => "E d/M",
    MMM => "MMM",
    MMMEd => "E d MMM",
    MMMMEd => "E d MMMM",
    "MMMMW-count-one" => "\N{U+03b5}\N{U+03b2}\N{U+03b4}\N{U+03bf}\N{U+03bc}\N{U+03ac}\N{U+03b4}\N{U+03b1} W \N{U+03c4}\N{U+03bf}\N{U+03c5} MMMM",
    "MMMMW-count-other" => "\N{U+03b5}\N{U+03b2}\N{U+03b4}\N{U+03bf}\N{U+03bc}\N{U+03ac}\N{U+03b4}\N{U+03b1} W \N{U+03c4}\N{U+03bf}\N{U+03c5} MMMM",
    MMMMd => "d MMMM",
    MMMd => "d MMM",
    Md => "d/M",
    d => "d",
    h => "h\N{U+202f}a",
    hm => "h:mm\N{U+202f}a",
    hms => "h:mm:ss\N{U+202f}a",
    hmsv => "h:mm:ss\N{U+202f}a v",
    hmv => "h:mm\N{U+202f}a v",
    ms => "mm:ss",
    y => "y",
    yM => "M/y",
    yMEd => "E d/M/y",
    yMMM => "MMM y",
    yMMMEd => "E d MMM y",
    yMMMM => "LLLL y",
    yMMMd => "d MMM y",
    yMd => "d/M/y",
    yQQQ => "QQQ y",
    yQQQQ => "QQQQ y",
    "yw-count-one" => "\N{U+03b5}\N{U+03b2}\N{U+03b4}\N{U+03bf}\N{U+03bc}\N{U+03ac}\N{U+03b4}\N{U+03b1} w \N{U+03c4}\N{U+03bf}\N{U+03c5} Y",
    "yw-count-other" => "\N{U+03b5}\N{U+03b2}\N{U+03b4}\N{U+03bf}\N{U+03bc}\N{U+03ac}\N{U+03b4}\N{U+03b1} w \N{U+03c4}\N{U+03bf}\N{U+03c5} Y",
  },
  code => "el-GR",
  date_format_full => "EEEE d MMMM y",
  date_format_long => "d MMMM y",
  date_format_medium => "d MMM y",
  date_format_short => "d/M/yy",
  datetime_format_full => "{1} - {0}",
  datetime_format_long => "{1} - {0}",
  datetime_format_medium => "{1}, {0}",
  datetime_format_short => "{1}, {0}",
  day_format_abbreviated => [
    "\N{U+0394}\N{U+03b5}\N{U+03c5}",
    "\N{U+03a4}\N{U+03c1}\N{U+03af}",
    "\N{U+03a4}\N{U+03b5}\N{U+03c4}",
    "\N{U+03a0}\N{U+03ad}\N{U+03bc}",
    "\N{U+03a0}\N{U+03b1}\N{U+03c1}",
    "\N{U+03a3}\N{U+03ac}\N{U+03b2}",
    "\N{U+039a}\N{U+03c5}\N{U+03c1}",
  ],
  day_format_narrow => [
    "\N{U+0394}",
    "\N{U+03a4}",
    "\N{U+03a4}",
    "\N{U+03a0}",
    "\N{U+03a0}",
    "\N{U+03a3}",
    "\N{U+039a}",
  ],
  day_format_wide => [
    "\N{U+0394}\N{U+03b5}\N{U+03c5}\N{U+03c4}\N{U+03ad}\N{U+03c1}\N{U+03b1}",
    "\N{U+03a4}\N{U+03c1}\N{U+03af}\N{U+03c4}\N{U+03b7}",
    "\N{U+03a4}\N{U+03b5}\N{U+03c4}\N{U+03ac}\N{U+03c1}\N{U+03c4}\N{U+03b7}",
    "\N{U+03a0}\N{U+03ad}\N{U+03bc}\N{U+03c0}\N{U+03c4}\N{U+03b7}",
    "\N{U+03a0}\N{U+03b1}\N{U+03c1}\N{U+03b1}\N{U+03c3}\N{U+03ba}\N{U+03b5}\N{U+03c5}\N{U+03ae}",
    "\N{U+03a3}\N{U+03ac}\N{U+03b2}\N{U+03b2}\N{U+03b1}\N{U+03c4}\N{U+03bf}",
    "\N{U+039a}\N{U+03c5}\N{U+03c1}\N{U+03b9}\N{U+03b1}\N{U+03ba}\N{U+03ae}",
  ],
  day_stand_alone_abbreviated => [
    "\N{U+0394}\N{U+03b5}\N{U+03c5}",
    "\N{U+03a4}\N{U+03c1}\N{U+03af}",
    "\N{U+03a4}\N{U+03b5}\N{U+03c4}",
    "\N{U+03a0}\N{U+03ad}\N{U+03bc}",
    "\N{U+03a0}\N{U+03b1}\N{U+03c1}",
    "\N{U+03a3}\N{U+03ac}\N{U+03b2}",
    "\N{U+039a}\N{U+03c5}\N{U+03c1}",
  ],
  day_stand_alone_narrow => [
    "\N{U+0394}",
    "\N{U+03a4}",
    "\N{U+03a4}",
    "\N{U+03a0}",
    "\N{U+03a0}",
    "\N{U+03a3}",
    "\N{U+039a}",
  ],
  day_stand_alone_wide => [
    "\N{U+0394}\N{U+03b5}\N{U+03c5}\N{U+03c4}\N{U+03ad}\N{U+03c1}\N{U+03b1}",
    "\N{U+03a4}\N{U+03c1}\N{U+03af}\N{U+03c4}\N{U+03b7}",
    "\N{U+03a4}\N{U+03b5}\N{U+03c4}\N{U+03ac}\N{U+03c1}\N{U+03c4}\N{U+03b7}",
    "\N{U+03a0}\N{U+03ad}\N{U+03bc}\N{U+03c0}\N{U+03c4}\N{U+03b7}",
    "\N{U+03a0}\N{U+03b1}\N{U+03c1}\N{U+03b1}\N{U+03c3}\N{U+03ba}\N{U+03b5}\N{U+03c5}\N{U+03ae}",
    "\N{U+03a3}\N{U+03ac}\N{U+03b2}\N{U+03b2}\N{U+03b1}\N{U+03c4}\N{U+03bf}",
    "\N{U+039a}\N{U+03c5}\N{U+03c1}\N{U+03b9}\N{U+03b1}\N{U+03ba}\N{U+03ae}",
  ],
  era_abbreviated => [
    "\N{U+03c0}.\N{U+03a7}.",
    "\N{U+03bc}.\N{U+03a7}.",
  ],
  era_narrow => [
    "\N{U+03c0}.\N{U+03a7}.",
    "\N{U+03bc}.\N{U+03a7}.",
  ],
  era_wide => [
    "\N{U+03c0}\N{U+03c1}\N{U+03bf} \N{U+03a7}\N{U+03c1}\N{U+03b9}\N{U+03c3}\N{U+03c4}\N{U+03bf}\N{U+03cd}",
    "\N{U+03bc}\N{U+03b5}\N{U+03c4}\N{U+03ac} \N{U+03a7}\N{U+03c1}\N{U+03b9}\N{U+03c3}\N{U+03c4}\N{U+03cc}\N{U+03bd}",
  ],
  first_day_of_week => 1,
  glibc_date_1_format => "%a %d %b %Y %r %Z",
  glibc_date_format => "%d/%m/%Y",
  glibc_datetime_format => "%a %d %b %Y %r %Z",
  glibc_time_12_format => "%I:%M:%S %p",
  glibc_time_format => "%r",
  language => "Greek",
  month_format_abbreviated => [
    "\N{U+0399}\N{U+03b1}\N{U+03bd}",
    "\N{U+03a6}\N{U+03b5}\N{U+03b2}",
    "\N{U+039c}\N{U+03b1}\N{U+03c1}",
    "\N{U+0391}\N{U+03c0}\N{U+03c1}",
    "\N{U+039c}\N{U+03b1}\N{U+0390}",
    "\N{U+0399}\N{U+03bf}\N{U+03c5}\N{U+03bd}",
    "\N{U+0399}\N{U+03bf}\N{U+03c5}\N{U+03bb}",
    "\N{U+0391}\N{U+03c5}\N{U+03b3}",
    "\N{U+03a3}\N{U+03b5}\N{U+03c0}",
    "\N{U+039f}\N{U+03ba}\N{U+03c4}",
    "\N{U+039d}\N{U+03bf}\N{U+03b5}",
    "\N{U+0394}\N{U+03b5}\N{U+03ba}",
  ],
  month_format_narrow => [
    "\N{U+0399}",
    "\N{U+03a6}",
    "\N{U+039c}",
    "\N{U+0391}",
    "\N{U+039c}",
    "\N{U+0399}",
    "\N{U+0399}",
    "\N{U+0391}",
    "\N{U+03a3}",
    "\N{U+039f}",
    "\N{U+039d}",
    "\N{U+0394}",
  ],
  month_format_wide => [
    "\N{U+0399}\N{U+03b1}\N{U+03bd}\N{U+03bf}\N{U+03c5}\N{U+03b1}\N{U+03c1}\N{U+03af}\N{U+03bf}\N{U+03c5}",
    "\N{U+03a6}\N{U+03b5}\N{U+03b2}\N{U+03c1}\N{U+03bf}\N{U+03c5}\N{U+03b1}\N{U+03c1}\N{U+03af}\N{U+03bf}\N{U+03c5}",
    "\N{U+039c}\N{U+03b1}\N{U+03c1}\N{U+03c4}\N{U+03af}\N{U+03bf}\N{U+03c5}",
    "\N{U+0391}\N{U+03c0}\N{U+03c1}\N{U+03b9}\N{U+03bb}\N{U+03af}\N{U+03bf}\N{U+03c5}",
    "\N{U+039c}\N{U+03b1}\N{U+0390}\N{U+03bf}\N{U+03c5}",
    "\N{U+0399}\N{U+03bf}\N{U+03c5}\N{U+03bd}\N{U+03af}\N{U+03bf}\N{U+03c5}",
    "\N{U+0399}\N{U+03bf}\N{U+03c5}\N{U+03bb}\N{U+03af}\N{U+03bf}\N{U+03c5}",
    "\N{U+0391}\N{U+03c5}\N{U+03b3}\N{U+03bf}\N{U+03cd}\N{U+03c3}\N{U+03c4}\N{U+03bf}\N{U+03c5}",
    "\N{U+03a3}\N{U+03b5}\N{U+03c0}\N{U+03c4}\N{U+03b5}\N{U+03bc}\N{U+03b2}\N{U+03c1}\N{U+03af}\N{U+03bf}\N{U+03c5}",
    "\N{U+039f}\N{U+03ba}\N{U+03c4}\N{U+03c9}\N{U+03b2}\N{U+03c1}\N{U+03af}\N{U+03bf}\N{U+03c5}",
    "\N{U+039d}\N{U+03bf}\N{U+03b5}\N{U+03bc}\N{U+03b2}\N{U+03c1}\N{U+03af}\N{U+03bf}\N{U+03c5}",
    "\N{U+0394}\N{U+03b5}\N{U+03ba}\N{U+03b5}\N{U+03bc}\N{U+03b2}\N{U+03c1}\N{U+03af}\N{U+03bf}\N{U+03c5}",
  ],
  month_stand_alone_abbreviated => [
    "\N{U+0399}\N{U+03b1}\N{U+03bd}",
    "\N{U+03a6}\N{U+03b5}\N{U+03b2}",
    "\N{U+039c}\N{U+03ac}\N{U+03c1}",
    "\N{U+0391}\N{U+03c0}\N{U+03c1}",
    "\N{U+039c}\N{U+03ac}\N{U+03b9}",
    "\N{U+0399}\N{U+03bf}\N{U+03cd}\N{U+03bd}",
    "\N{U+0399}\N{U+03bf}\N{U+03cd}\N{U+03bb}",
    "\N{U+0391}\N{U+03cd}\N{U+03b3}",
    "\N{U+03a3}\N{U+03b5}\N{U+03c0}",
    "\N{U+039f}\N{U+03ba}\N{U+03c4}",
    "\N{U+039d}\N{U+03bf}\N{U+03ad}",
    "\N{U+0394}\N{U+03b5}\N{U+03ba}",
  ],
  month_stand_alone_narrow => [
    "\N{U+0399}",
    "\N{U+03a6}",
    "\N{U+039c}",
    "\N{U+0391}",
    "\N{U+039c}",
    "\N{U+0399}",
    "\N{U+0399}",
    "\N{U+0391}",
    "\N{U+03a3}",
    "\N{U+039f}",
    "\N{U+039d}",
    "\N{U+0394}",
  ],
  month_stand_alone_wide => [
    "\N{U+0399}\N{U+03b1}\N{U+03bd}\N{U+03bf}\N{U+03c5}\N{U+03ac}\N{U+03c1}\N{U+03b9}\N{U+03bf}\N{U+03c2}",
    "\N{U+03a6}\N{U+03b5}\N{U+03b2}\N{U+03c1}\N{U+03bf}\N{U+03c5}\N{U+03ac}\N{U+03c1}\N{U+03b9}\N{U+03bf}\N{U+03c2}",
    "\N{U+039c}\N{U+03ac}\N{U+03c1}\N{U+03c4}\N{U+03b9}\N{U+03bf}\N{U+03c2}",
    "\N{U+0391}\N{U+03c0}\N{U+03c1}\N{U+03af}\N{U+03bb}\N{U+03b9}\N{U+03bf}\N{U+03c2}",
    "\N{U+039c}\N{U+03ac}\N{U+03b9}\N{U+03bf}\N{U+03c2}",
    "\N{U+0399}\N{U+03bf}\N{U+03cd}\N{U+03bd}\N{U+03b9}\N{U+03bf}\N{U+03c2}",
    "\N{U+0399}\N{U+03bf}\N{U+03cd}\N{U+03bb}\N{U+03b9}\N{U+03bf}\N{U+03c2}",
    "\N{U+0391}\N{U+03cd}\N{U+03b3}\N{U+03bf}\N{U+03c5}\N{U+03c3}\N{U+03c4}\N{U+03bf}\N{U+03c2}",
    "\N{U+03a3}\N{U+03b5}\N{U+03c0}\N{U+03c4}\N{U+03ad}\N{U+03bc}\N{U+03b2}\N{U+03c1}\N{U+03b9}\N{U+03bf}\N{U+03c2}",
    "\N{U+039f}\N{U+03ba}\N{U+03c4}\N{U+03ce}\N{U+03b2}\N{U+03c1}\N{U+03b9}\N{U+03bf}\N{U+03c2}",
    "\N{U+039d}\N{U+03bf}\N{U+03ad}\N{U+03bc}\N{U+03b2}\N{U+03c1}\N{U+03b9}\N{U+03bf}\N{U+03c2}",
    "\N{U+0394}\N{U+03b5}\N{U+03ba}\N{U+03ad}\N{U+03bc}\N{U+03b2}\N{U+03c1}\N{U+03b9}\N{U+03bf}\N{U+03c2}",
  ],
  name => "Greek Greece",
  native_language => "\N{U+0395}\N{U+03bb}\N{U+03bb}\N{U+03b7}\N{U+03bd}\N{U+03b9}\N{U+03ba}\N{U+03ac}",
  native_name => "\N{U+0395}\N{U+03bb}\N{U+03bb}\N{U+03b7}\N{U+03bd}\N{U+03b9}\N{U+03ba}\N{U+03ac} \N{U+0395}\N{U+03bb}\N{U+03bb}\N{U+03ac}\N{U+03b4}\N{U+03b1}",
  native_script => undef,
  native_territory => "\N{U+0395}\N{U+03bb}\N{U+03bb}\N{U+03ac}\N{U+03b4}\N{U+03b1}",
  native_variant => undef,
  quarter_format_abbreviated => [
    "\N{U+03a4}1",
    "\N{U+03a4}2",
    "\N{U+03a4}3",
    "\N{U+03a4}4",
  ],
  quarter_format_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_format_wide => [
    "1\N{U+03bf} \N{U+03c4}\N{U+03c1}\N{U+03af}\N{U+03bc}\N{U+03b7}\N{U+03bd}\N{U+03bf}",
    "2\N{U+03bf} \N{U+03c4}\N{U+03c1}\N{U+03af}\N{U+03bc}\N{U+03b7}\N{U+03bd}\N{U+03bf}",
    "3\N{U+03bf} \N{U+03c4}\N{U+03c1}\N{U+03af}\N{U+03bc}\N{U+03b7}\N{U+03bd}\N{U+03bf}",
    "4\N{U+03bf} \N{U+03c4}\N{U+03c1}\N{U+03af}\N{U+03bc}\N{U+03b7}\N{U+03bd}\N{U+03bf}",
  ],
  quarter_stand_alone_abbreviated => [
    "\N{U+03a4}1",
    "\N{U+03a4}2",
    "\N{U+03a4}3",
    "\N{U+03a4}4",
  ],
  quarter_stand_alone_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_stand_alone_wide => [
    "1\N{U+03bf} \N{U+03c4}\N{U+03c1}\N{U+03af}\N{U+03bc}\N{U+03b7}\N{U+03bd}\N{U+03bf}",
    "2\N{U+03bf} \N{U+03c4}\N{U+03c1}\N{U+03af}\N{U+03bc}\N{U+03b7}\N{U+03bd}\N{U+03bf}",
    "3\N{U+03bf} \N{U+03c4}\N{U+03c1}\N{U+03af}\N{U+03bc}\N{U+03b7}\N{U+03bd}\N{U+03bf}",
    "4\N{U+03bf} \N{U+03c4}\N{U+03c1}\N{U+03af}\N{U+03bc}\N{U+03b7}\N{U+03bd}\N{U+03bf}",
  ],
  script => undef,
  territory => "Greece",
  time_format_full => "h:mm:ss\N{U+202f}a zzzz",
  time_format_long => "h:mm:ss\N{U+202f}a z",
  time_format_medium => "h:mm:ss\N{U+202f}a",
  time_format_short => "h:mm\N{U+202f}a",
  variant => undef,
  version => 42,
}
